# turvallisuusneuvonta

[![license](https://img.shields.io/github/license/sthagen/turvallisuusneuvonta.svg?style=flat)](https://github.com/sthagen/turvallisuusneuvonta/blob/default/LICENSE)
[![version](https://img.shields.io/pypi/v/turvallisuusneuvonta.svg?style=flat)](https://pypi.python.org/pypi/turvallisuusneuvonta/)
[![downloads](https://pepy.tech/badge/turvallisuusneuvonta/month)](https://pepy.tech/project/turvallisuusneuvonta)
[![wheel](https://img.shields.io/pypi/wheel/turvallisuusneuvonta.svg?style=flat)](https://pypi.python.org/pypi/turvallisuusneuvonta/)
[![supported-versions](https://img.shields.io/pypi/pyversions/turvallisuusneuvonta.svg?style=flat)](https://pypi.python.org/pypi/turvallisuusneuvonta/)
[![supported-implementations](https://img.shields.io/pypi/implementation/turvallisuusneuvonta.svg?style=flat)](https://pypi.python.org/pypi/turvallisuusneuvonta/)

Security advisory (Finnish: turvallisuusneuvonta) audit tool.

## Status

Experimental.

**Note**: The default branch is default.
